@@ -1,8 +1,8 @@
-from typing import Literal, List, Dict, Optional
+from typing import Dict, List, Literal, Optional
 
 from pydantic import BaseModel
 
-from .customers import CustomerProduct, CustomerFeature, CustomerInvoice
+from .customers import CustomerFeature, CustomerInvoice, CustomerProduct
 from .products import Product
 
 __all__ = ("Feature", "FeaturePreview", "Entity")
