@@ -1,12 +1,12 @@
-from typing import Optional, List
+from typing import List, Optional
 
 from pydantic import BaseModel
 
-from .meta import AppEnv, CheckoutLine, AttachOption, Cycle
-from .products import ProductItem, FreeTrial, Product
-from .customers import PricingTableProduct
+from .customers import Customer, PricingTableProduct
+from .env import AppEnv
 from .features import FeaturePreview
-from .products import ProductPreview
+from .meta import FeatureOptions, QueryDP
+from .products import FreeTrial, Product, ProductItem, ProductPreview
 
 __all__ = ("AttachResponse", "CheckResponse")
 
@@ -46,19 +46,6 @@ class UsageResponse(BaseModel):
     feature_id: str
 
 
-class CheckoutResponse(BaseModel):
-    url: Optional[str] = None
-    customer_id: str
-    has_prorations: bool
-    total: float
-    currency: str
-    lines: List[CheckoutLine]
-    options: List[AttachOption]
-    product: Product
-    current_product: Optional[Product] = None
-    next_cycle: Optional[Cycle] = None
-
-
 class BillingPortalResponse(BaseModel):
     url: str
     customer_id: str
@@ -91,9 +78,8 @@ class ReferralRedeemResponse(BaseModel):
     reward_id: str
 
 
-class ProductCancelResponse(BaseModel):
+class CancelResponse(BaseModel):
     success: bool
-    message: str
     customer_id: str
     product_id: str
 
@@ -102,5 +88,44 @@ class PricingTableResponse(BaseModel):
     list: List[PricingTableProduct]
 
 
+class CheckoutLine(BaseModel):
+    description: str
+    amount: float
+    item: ProductItem
+
+
+class CheckoutNextCycle(BaseModel):
+    starts_at: int
+    total: float
+
+
+class CheckoutResponse(BaseModel):
+    url: Optional[str] = None
+    customer_id: str
+    has_prorations: bool
+    lines: List[CheckoutLine]
+    total: float
+    currency: str
+    options: List[FeatureOptions]
+    product: Optional[Product] = None
+    current_product: Optional[Product] = None
+    next_cycle: Optional[CheckoutNextCycle] = None
+
+
 class ListProductResponse(BaseModel):
     list: List[Product]
+
+
+class ListCustomerResponse(BaseModel):
+    list: List[Customer]
+    total: int
+    limit: int
+    offset: int
+
+
+class QueryResponse(BaseModel):
+    list: List[QueryDP]
+
+
+class TransferProductResponse(BaseModel):
+    success: bool
