@@ -1,9 +1,9 @@
-from typing import Dict, Any, Callable, Type, TypeVar, Set
+import random
+from typing import Any, Callable, Dict, Set, Type, TypeVar
 
 from pydantic import BaseModel, ValidationError
 
-from .error import AutumnValidationError, AutumnHTTPError
-
+from .error import AutumnHTTPError, AutumnValidationError
 
 T = TypeVar("T", bound=BaseModel)
 
@@ -61,3 +61,22 @@ def _check_response(status_code: int, data: Dict[str, Any]) -> None:
             code,
             status_code,
         )
+
+
+class ExponentialBackoff:
+    def __init__(self):
+        rand = random.Random()
+        rand.seed()
+
+        self._rand = rand
+        self._base = 2
+        self._state = 0
+
+    def tick(self):
+        self._state += 1
+
+    @property
+    def bedtime(self):
+        raw_time = self._base**self._state
+        jitter = self._rand.uniform(0, 1)
+        return raw_time + jitter
